hanzo-kernels 0.9.2

Minimalist ML framework.
docs.rs failed to build hanzo-kernels-0.9.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

hanzo-kernels

This crate contains CUDA kernels used from hanzo-ml. Some of these implementations come from the dfdx crate.